summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmboxedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmboxedit.h')
-rw-r--r--kpovmodeler/pmboxedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmboxedit.h b/kpovmodeler/pmboxedit.h
index 7fd6fadc..f9f0bf6d 100644
--- a/kpovmodeler/pmboxedit.h
+++ b/kpovmodeler/pmboxedit.h
@@ -35,12 +35,13 @@ class PMVectorEdit;
class PMBoxEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMBoxEdit with parent and name
*/
- PMBoxEdit( TQWidget* parent, const char* name = 0 );
+ PMBoxEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class PMVectorEdit;
public:
/**
- * Creates a PMBoxEdit with parent and name
+ * Creates a PMBoxEdit with tqparent and name
*/